You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by br...@apache.org on 2013/12/02 14:07:06 UTC

svn commit: r1547002 - in /subversion/trunk/subversion: include/svn_repos.h libsvn_repos/dump.c svnadmin/svnadmin.c tests/cmdline/svnadmin_tests.py

Author: brane
Date: Mon Dec  2 13:07:06 2013
New Revision: 1547002

URL: http://svn.apache.org/r1547002
Log:
Rename the 'svnadmin verify's --check-ucs-normalization flag to just
--check-normalization, and update all internal symbols accordingly.

* subversion/include/svn_repos.h (svn_repos_verify_fs3):
   Rename 'check_ucs_norm' to 'check_normalization' and update docstring.
  (svn_repos_verify_fs3): Update docstring.
* subversion/libsvn_repos/dump.c:
   Rename 'check_ucs_norm' to 'check_normalization' everywhere.
* subversion/svnadmin/svnadmin.c: As above, and also rename the option
   keyword and command-line option name.
* subversion/tests/cmdline/svnadmin_tests.py (verify_denormalized_names):
   Update the invocation of 'svnadmin verify'.

Modified:
    subversion/trunk/subversion/include/svn_repos.h
    subversion/trunk/subversion/libsvn_repos/dump.c
    subversion/trunk/subversion/svnadmin/svnadmin.c
    subversion/trunk/subversion/tests/cmdline/svnadmin_tests.py

Modified: subversion/trunk/subversion/include/svn_repos.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_repos.h?rev=1547002&r1=1547001&r2=1547002&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_repos/dump.c (original)
+++ subversion/trunk/subversion/libsvn_repos/dump.c Mon Dec  2 13:07:06 2013
@@ -382,7 +382,7 @@ struct edit_baton
   svn_boolean_t verify;
 
   /* True if checking UCS normalization during a verify. */
-  svn_boolean_t check_ucs_norm;
+  svn_boolean_t check_normalization;
 
   /* The first revision dumped in this dumpstream. */
   svn_revnum_t oldest_dumped_rev;
@@ -1155,7 +1155,7 @@ dump_node(struct edit_baton *eb,
       /* If we're checking UCS normalization, also parse any changed
          mergeinfo and warn about denormalized paths and name
          collisions there. */
-      if (eb->verify && eb->check_ucs_norm && eb->notify_func)
+      if (eb->verify && eb->check_normalization && eb->notify_func)
         {
           /* N.B.: This hash lookup happens only once; the conditions
              for verifying historic mergeinfo references and checking
@@ -1372,7 +1372,7 @@ add_directory(const char *path,
 
   /* Check for UCS normalization and name clashes, but only if this is
      actually a new name in the parent, not a replacement. */
-  if (!val && eb->verify && eb->check_ucs_norm && eb->notify_func)
+  if (!val && eb->verify && eb->check_normalization && eb->notify_func)
     {
       pb->check_name_collision = TRUE;
       SVN_ERR(check_path_normalization(
@@ -1481,7 +1481,7 @@ add_file(const char *path,
 
   /* Check for UCS normalization and name clashes, but only if this is
      actually a new name in the parent, not a replacement. */
-  if (!val && eb->verify && eb->check_ucs_norm && eb->notify_func)
+  if (!val && eb->verify && eb->check_normalization && eb->notify_func)
     {
       pb->check_name_collision = TRUE;
       SVN_ERR(check_path_normalization(
@@ -1656,7 +1656,7 @@ get_dump_editor(const svn_delta_editor_t
                 svn_revnum_t oldest_dumped_rev,
                 svn_boolean_t use_deltas,
                 svn_boolean_t verify,
-                svn_boolean_t check_ucs_norm,
+                svn_boolean_t check_normalization,
                 svn_cache__t *verified_dirents_cache,
                 apr_pool_t *pool)
 {
@@ -1680,7 +1680,7 @@ get_dump_editor(const svn_delta_editor_t
   eb->current_rev = to_rev;
   eb->use_deltas = use_deltas;
   eb->verify = verify;
-  eb->check_ucs_norm = check_ucs_norm;
+  eb->check_normalization = check_normalization;
   eb->found_old_reference = found_old_reference;
   eb->found_old_mergeinfo = found_old_mergeinfo;
   eb->verified_dirents_cache = verified_dirents_cache;
@@ -2163,7 +2163,7 @@ verify_one_revision(svn_fs_t *fs,
                     svn_repos_notify_func_t notify_func,
                     void *notify_baton,
                     svn_revnum_t start_rev,
-                    svn_boolean_t check_ucs_norm,
+                    svn_boolean_t check_normalization,
                     svn_cancel_func_t cancel_func,
                     void *cancel_baton,
                     svn_cache__t *verified_dirents_cache,
@@ -2185,7 +2185,7 @@ verify_one_revision(svn_fs_t *fs,
                           notify_func, notify_baton,
                           start_rev,
                           FALSE, TRUE, /* use_deltas, verify */
-                          check_ucs_norm,
+                          check_normalization,
                           verified_dirents_cache,
                           scratch_pool));
   SVN_ERR(svn_delta_get_cancellation_editor(cancel_func, cancel_baton,
@@ -2263,7 +2263,7 @@ svn_repos_verify_fs3(svn_repos_t *repos,
                      svn_revnum_t start_rev,
                      svn_revnum_t end_rev,
                      svn_boolean_t keep_going,
-                     svn_boolean_t check_ucs_norm,
+                     svn_boolean_t check_normalization,
                      svn_repos_notify_func_t notify_func,
                      void *notify_baton,
                      svn_cancel_func_t cancel_func,
@@ -2359,7 +2359,7 @@ svn_repos_verify_fs3(svn_repos_t *repos,
 
       /* Wrapper function to catch the possible errors. */
       err = verify_one_revision(fs, rev, notify_func, notify_baton,
-                                start_rev, check_ucs_norm,
+                                start_rev, check_normalization,
                                 cancel_func, cancel_baton,
                                 verified_dirents_cache, iterpool);
 

Modified: subversion/trunk/subversion/svnadmin/svnadmin.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/svnadmin/svnadmin.c?rev=1547002&r1=1547001&r2=1547002&view=diff
==============================================================================
--- subversion/trunk/subversion/svnadmin/svnadmin.c (original)
+++ subversion/trunk/subversion/svnadmin/svnadmin.c Mon Dec  2 13:07:06 2013
@@ -198,7 +198,7 @@ enum svnadmin__cmdline_options_t
     svnadmin__pre_1_5_compatible,
     svnadmin__pre_1_6_compatible,
     svnadmin__compatible_version,
-    svnadmin__check_ucs_normalization
+    svnadmin__check_normalization
   };
 
 /* Option codes and descriptions.
@@ -303,7 +303,7 @@ static const apr_getopt_option_t options
 
     {"file", 'F', 1, N_("read repository paths from file ARG")},
 
-    {"check-ucs-normalization", svnadmin__check_ucs_normalization, 0,
+    {"check-normalization", svnadmin__check_normalization, 0,
      N_("report paths in the filesystem and mergeinfo\n"
         "                             that are not normalized to Unicode Normalization\n"
         "                             Form C, and any names within the same directory\n"
@@ -504,7 +504,7 @@ static const svn_opt_subcommand_desc2_t 
    ("usage: svnadmin verify REPOS_PATH\n\n"
     "Verify the data stored in the repository.\n"),
    {'t', 'r', 'q', svnadmin__keep_going, 'M',
-    svnadmin__check_ucs_normalization} },
+    svnadmin__check_normalization} },
 
   { NULL, NULL, {0}, NULL, {0} }
 };
@@ -533,7 +533,7 @@ struct svnadmin_opt_state
   svn_boolean_t bypass_hooks;                       /* --bypass-hooks */
   svn_boolean_t wait;                               /* --wait */
   svn_boolean_t keep_going;                         /* --keep-going */
-  svn_boolean_t check_ucs_norm;                     /* --check-ucs-normalization */
+  svn_boolean_t check_normalization;                /* --check-normalization */
   svn_boolean_t bypass_prop_validation;             /* --bypass-prop-validation */
   enum svn_repos_load_uuid uuid_action;             /* --ignore-uuid,
                                                        --force-uuid */
@@ -1752,7 +1752,7 @@ subcommand_verify(apr_getopt_t *os, void
 
   verify_err = svn_repos_verify_fs3(repos, lower, upper,
                                     opt_state->keep_going,
-                                    opt_state->check_ucs_norm,
+                                    opt_state->check_normalization,
                                     !opt_state->quiet
                                     ? repos_notify_handler : NULL,
                                     &notify_baton, check_cancel,
@@ -2430,8 +2430,8 @@ sub_main(int *exit_code, int argc, const
       case svnadmin__keep_going:
         opt_state.keep_going = TRUE;
         break;
-      case svnadmin__check_ucs_normalization:
-        opt_state.check_ucs_norm = TRUE;
+      case svnadmin__check_normalization:
+        opt_state.check_normalization = TRUE;
         break;
       case svnadmin__fs_type:
         SVN_ERR(svn_utf_cstring_to_utf8(&opt_state.fs_type, opt_arg, pool));

Modified: subversion/trunk/subversion/tests/cmdline/svnadmin_tests.py
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/tests/cmdline/svnadmin_tests.py?rev=1547002&r1=1547001&r2=1547002&view=diff
==============================================================================
--- subversion/trunk/subversion/tests/cmdline/svnadmin_tests.py (original)
+++ subversion/trunk/subversion/tests/cmdline/svnadmin_tests.py Mon Dec  2 13:07:06 2013
@@ -2077,7 +2077,7 @@ def verify_denormalized_names(sbox):
   load_dumpstream(sbox, open(dumpfile_location).read())
 
   exit_code, output, errput = svntest.main.run_svnadmin(
-    "verify", "--check-ucs-normalization", sbox.repo_dir)
+    "verify", "--check-normalization", sbox.repo_dir)
 
   expected_output_regex_list = [
     ".*Verified revision 0.",
--- subversion/trunk/subversion/include/svn_repos.h (original)
+++ subversion/trunk/subversion/include/svn_repos.h Mon Dec  2 13:07:06 2013
@@ -2694,11 +2694,11 @@ svn_repos_info_format(int *repos_format,
  * not notified. Finally, return an error if there were any failures during
  * verification, or SVN_NO_ERROR if there were no failures.
  *
  * If @a check_ucs_norm is @c TRUE, verify that all path names in the
  * repository and in svn:mergeinfo entries are normaized to Unicode
  * Normalization Form C, and report any name collisions within the
  * same directory or svn:mergeinfo property where the names differ only
  * in character representation, but are otherwise identical.
  *
  * @since New in 1.9.
  */
@@ -2707,7 +2707,7 @@ svn_repos_verify_fs3(svn_repos_t *repos,
                      svn_revnum_t start_rev,
                      svn_revnum_t end_rev,
                      svn_boolean_t keep_going,
-                     svn_boolean_t check_ucs_norm,
+                     svn_boolean_t check_normalization,
                      svn_repos_notify_func_t notify_func,
                      void *notify_baton,
                      svn_cancel_func_t cancel,
@@ -2716,7 +2716,7 @@ svn_repos_verify_fs3(svn_repos_t *repos,
 
 /**
  * Like svn_repos_verify_fs3(), but with @a keep_going and
- * @a check_ucs_norm set to @c FALSE.
+ * @a check_normalization set to @c FALSE.
  *
  * @since New in 1.7.
  * @deprecated Provided for backward compatibility with the 1.8 API.
@@ -2694,11 +2694,11 @@ svn_repos_info_format(int *repos_format,
  * verification, or SVN_NO_ERROR if there were no failures.
  *
- * If @a check_ucs_norm is @c TRUE, verify that all path names in the
- * repository and in svn:mergeinfo entries are normaized to Unicode
- * Normalization Form C, and report any name collisions within the
- * same directory or svn:mergeinfo property where the names differ only
- * in character representation, but are otherwise identical.
+ * If @a check_normalization is @c TRUE, verify that all path names in
+ * the repository and in @c svn:mergeinfo entries are normaized to
+ * Unicode Normalization Form C, and report any name collisions within
+ * the same directory or svn:mergeinfo property where the names differ
+ * only in character representation, but are otherwise identical.
  *
  * @since New in 1.9.

Modified: subversion/trunk/subversion/libsvn_repos/dump.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_repos/dump.c?rev=1547002&r1=1547001&r2=1547002&view=diff
==============================================================================